videocollection/tsrc/stubs/inc/hblistview.h
changeset 35 3738fe97f027
parent 34 bbb98528c666
child 36 8aed59de29f9
--- a/videocollection/tsrc/stubs/inc/hblistview.h	Thu Apr 01 23:22:15 2010 +0300
+++ b/videocollection/tsrc/stubs/inc/hblistview.h	Thu Apr 01 23:32:44 2010 +0300
@@ -15,10 +15,15 @@
 *
 */
 
-
 #ifndef HBLISTVIEW_H
 #define HBLISTVIEW_H
 
+#include "hbwidget.h"
+#include "hblistviewitem.h"
+#include "hbscrollbar.h"
+#include "hbabstractitemview.h"
+#include "videosortfilterproxymodel.h"
+
 #include <QGraphicsItem>
 #include <QModelIndex>
 #include <qgraphicswidget.h>
@@ -26,11 +31,6 @@
 #include <QPointF>
 #include <qitemselectionmodel.h>
 
-#include "videosortfilterproxymodel.h"
-#include "hblistviewitem.h"
-#include "hbscrollbar.h"
-#include "hbabstractitemview.h"
-
 class HbScrollArea
 {
 public:
@@ -49,7 +49,7 @@
 class HbListView : public HbAbstractItemView
 {
     Q_OBJECT
-   
+    
 public:
 
 signals:
@@ -63,13 +63,18 @@
      * dummy signal
      */
     void scrollingEnded();
+    
+    /**
+     * dummy signal
+     */
+    void scrollingStarted();
         
 public:  
     /**
      * contructor
      */
     HbListView(QGraphicsItem *parent = 0) :
-            mItem(0)
+            mItem(0), mVerticalSB(0), mSelectionModel(0)
     {
         Q_UNUSED(parent);
         mItem = new HbListViewItem();
@@ -161,7 +166,7 @@
     {
         mLatestUniformItemSizes = value;
     }
-
+    
     /**
      * dummy method
      */
@@ -220,7 +225,7 @@
      */
     void clearSelection()
     {
-        // nop
+        mAllSelectedStatus = 0;
     }
     
     /**
@@ -238,7 +243,7 @@
      */
     void selectAll()
     {
-        // nop
+        mAllSelectedStatus = 1;
     }
     
     /**
@@ -252,6 +257,15 @@
         }
         return mSelectionModel;
     }
+
+    /**
+     * dummy method
+     */
+    HbAbstractViewItem* itemAtPosition(const QPointF &position)
+    {
+        return mItem;
+    }
+public:
     
     /**
      * items to be returned from visibleItems
@@ -263,14 +277,20 @@
      */
     static HbAbstractItemView::SelectionMode mSelectionMode;
     
-    
     /**
      * provided model
      */
     static VideoSortFilterProxyModel *mLatestModel;
     
     /**
-     * item to returned from listItemPrototype
+     * -1 == initialized
+     *  0 == nothing selected
+     *  1 == all selected
+     */
+    static int mAllSelectedStatus;
+    
+    /**
+     * item to returned from listItemPrototype and from itemAtPosition
      */
     HbListViewItem *mItem;
     
@@ -283,7 +303,7 @@
      * selection model
      */
     QItemSelectionModel *mSelectionModel;
-    
+
     /**
      * if true verticalScrollBar return null
      */